/*
 * Copyright 2004-2005 Jeremias Maerki
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.xml.graphics;

/**
 * Represents basic document metadata that can be set as an option on the 
 * XGResult. Implementations can subclass this class to provide additional
 * information. All items here are not mandatory. Implementations may ignore
 * this object entirely but shouldn't throw an Exception when it is set.
 * 
 * @author Jeremias Maerki
 */
public class DocumentMetadata {

    /** For use as a key to XGResult.setOutputProperty() */
    public static final String KEY = "metadata";
    
    private String author;
    private String title;
    private String keywords;
    private String creator;
    
    
    /**
     * @return Returns the author.
     */
    public String getAuthor() {
        return author;
    }
    
    /**
     * @param author The author to set.
     */
    public void setAuthor(String author) {
        this.author = author;
    }
    
    /**
     * @return Returns the keywords.
     */
    public String getKeywords() {
        return keywords;
    }
    
    /**
     * @param keywords The keywords to set.
     */
    public void setKeywords(String keywords) {
        this.keywords = keywords;
    }
    
    /**
     * @return Returns the title.
     */
    public String getTitle() {
        return title;
    }
    
    /**
     * @param title The title to set.
     */
    public void setTitle(String title) {
        this.title = title;
    }
    
    /**
     * @param creator The name of the application that created the original 
     * document now being converted to a different form.
     */
    public void setCreator(String creator) {
        this.creator = creator;
    }
    
    /**
     * @return the name of the application that created the original 
     * document now being converted to a different form.
     */
    public String getCreator() {
        return this.creator;
    }
    
}
