/*
 * Copyright 2004-2005 Jeremias Maerki
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.xml.graphics;

import org.xml.sax.ContentHandler;

/**
 * <p>The XGProcessorHandler is the equivalent of the JAXP TransformerHandler.
 * For FO processing you will mostly use this interface as it integrates
 * nicely into the SAX-oriented JAXP pattern.
 * </p>
 * <p>An example:</p>
 * <pre>
 * //Set up the XGProcessor
 * XGProcessorFactory factory = new SomeXGProcessorFactory();
 * XGProcessorHandler xgHandler = factory.newXGProcessorHandler();
 * 
 * //Set up the source, target and XSLT stylesheet      
 * Source src = new StreamSource(new File("C:/temp/data.xml"));
 * Source xslt = new StreamSource(new File("C:/temp/convert.xsl"));
 * XGResult pdf = new StreamXGResult("application/pdf", 
 *         new File("C:/temp/out.pdf"));
 * xgHandler.setResult(pdf);
 * 
 * //Setup the JAXP Transformer      
 * TransformerFactory tf = TransformerFactory.newInstance();
 * Transformer transformer = tf.newTransformer(xslt);
 * 
 * //This links the SAX output from the XSLT stage to the input of the FO stage
 * Result res = new SAXResult(xgHandler);
 * 
 * //Start the processing run
 * transformer.transform(src, res);
 * </pre>
 * 
 * @author Jeremias Maerki
 */
public interface XGProcessorHandler extends ContentHandler {

    void setResult(XGResult result);
    
    XGProcessor getXGProcessor();

}
