/*
 * Copyright 2004-2005 Jeremias Maerki
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.xml.graphics.helpers;

import java.util.List;

import javax.xml.transform.URIResolver;

import org.xml.graphics.XGEventListener;
import org.xml.graphics.XGProcessor;

/**
 * Abstract base class that can be used as a starting point for XGProcessor 
 * implementations.
 * 
 * @author Jeremias Maerki
 */
public abstract class AbstractXGProcessor implements XGProcessor {

    protected List listeners = new java.util.LinkedList();
    protected URIResolver resolver;
    
    /**
     * @see org.xml.graphics.XGProcessor#addEventListener(org.xml.graphics.XGEventListener)
     */
    public void addEventListener(XGEventListener listener) {
        listeners.add(listener);
    }

    /**
     * @see org.xml.graphics.XGProcessor#removeEventListener(org.xml.graphics.XGEventListener)
     */
    public void removeEventListener(XGEventListener listener) {
        listeners.remove(listener);
    }

    /**
     * @see org.xml.graphics.XGProcessor#setURIResolver(javax.xml.transform.URIResolver)
     */
    public void setURIResolver(URIResolver resolver) {
        this.resolver = resolver;
    }
    
    /**
     * @see org.xml.graphics.XGProcessor#getURIResolver()
     */
    public URIResolver getURIResolver() {
        return this.resolver;
    }
    
    /**
     * @see org.xml.graphics.XGProcessor#setParameter(java.lang.String, java.lang.Object)
    public void setParameter(String name, Object value) {
        //Ignore any parameters set
    }
     */

    /**
     * @see org.xml.graphics.XGProcessor#getParameter(java.lang.String)
    public Object getParameter(String name) {
        throw new IllegalArgumentException("Unsupported parameter: " + name);
    }
     */
    
}
