/*
 * Copyright 2004-2005 Jeremias Maerki
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.xml.graphics.helpers;

import java.io.IOException;
import java.io.InputStream;
import java.net.MalformedURLException;
import java.net.URL;
import java.util.Collection;
import java.util.Iterator;

import javax.xml.parsers.DocumentBuilder;
import javax.xml.parsers.DocumentBuilderFactory;

import org.w3c.dom.Document;
import org.w3c.dom.Element;
import org.w3c.dom.NodeList;

/**
 * This bean describes what a deployment package consists of.
 *  
 * @author Jeremias Maerki
 */
public class DeploymentPackage {

    private String id;
    private String description;
    private String mainClass;
    private Collection jars = new java.util.ArrayList();
    
    public DeploymentPackage() {
        //nop
    }
    
    public DeploymentPackage(String mainClass) {
        setMainClass(mainClass);
    }
    
    public String getID() {
        return this.id;
    }
    
    public void setID(String id) {
        this.id = id;
    }
    
    public String getDescription() {
        return this.description;
    }
    
    public void setDescription(String description) {
        this.description = description;
    }
    
    public String getMainClass() {
        return this.mainClass;
    }
    
    public void setMainClass(String mainClass) {
        this.mainClass = mainClass;
    }
    
    public Iterator iterateJARs() {
        return this.jars.iterator();
    }

    public URL[] getJARs() {
        return (URL[])this.jars.toArray(new URL[this.jars.size()]);
    }
    
    public void addJAR(URL jar) {
        //System.out.println(jar.toString());
        this.jars.add(jar);
    }
    
    public static DeploymentPackage readFromURL(URL url) throws IOException {
        InputStream in = url.openStream();
        try {
            return readFromStream(in, url);
        } finally {
            in.close();
        }
    }
    
    public static DeploymentPackage readFromStream(InputStream in, URL baseURL) throws IOException {
        try {
            DocumentBuilderFactory factory = DocumentBuilderFactory.newInstance();
            factory.setValidating(false);
            DocumentBuilder builder = factory.newDocumentBuilder();
            Document doc = builder.parse(in);
            doc.normalize();
            Element root = doc.getDocumentElement();
            DeploymentPackage pkg = new DeploymentPackage();
            pkg.setID(root.getAttribute("id"));
            pkg.setDescription(root.getAttribute("description"));
            pkg.setMainClass(root.getAttribute("main-class"));
            URL effBaseURL = baseURL;
            if (root.hasAttribute("codebase")) {
                String codebase = root.getAttribute("codebase");
                effBaseURL = URLBuilder.toURL(codebase);
            }
            NodeList jars = root.getElementsByTagName("jar");
            for (int i = 0; i < jars.getLength(); i++) {
                String jar = DOMUtil.getElementText((Element)jars.item(i)); 
                try {
                    pkg.addJAR(URLBuilder.toURL(effBaseURL, jar));
                } catch (MalformedURLException e) {
                    throw new IllegalArgumentException("Invalid JAR: " + e.getMessage());
                }
            }
            return pkg;
        } catch (IOException e) {
            throw e;
        } catch (Exception e) {
            throw new RuntimeException(e.getMessage());
        }
    }
}
