/*
 * Copyright 2004-2005 Jeremias Maerki
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.xml.graphics.helpers;

import java.io.File;
import java.net.MalformedURLException;
import java.net.URL;

/**
 * Constructs URLs from Strings (filenames or URLs).
 * 
 * @author Jeremias Maerki
 */
public class URLBuilder {

    public static File toFile(String spec) {
        if (spec == null) throw new NullPointerException("spec must not be null");
        String s = spec;
        if (s.startsWith("file:")) {
            int pos = 5;
            while (s.charAt(pos) == '/') {
                pos++;
            }
            s = s.substring(pos);
        }
        File f = new File(s);
        if (f.exists()) {
            return f;
        } else {
            return null;
        }
    }
    
    public static URL toFileURL(String spec) throws MalformedURLException {
        File f = toFile(spec);
        if (f != null) {
            return f.toURL();
        } else {
            return null;
        }
    }
    
    public static URL toURL(String spec) throws MalformedURLException {
        if (spec == null) throw new NullPointerException("spec must not be null");
        URL url = toFileURL(spec);
        if (url == null) {
            if (spec.indexOf("://") > 0 || spec.startsWith("file:/")) {
                return new URL(spec);
            } else {
                throw new MalformedURLException("File not found: " + spec);
            }
        }
        return url;
    }
    
    public static URL toURL(URL baseURL, String spec) throws MalformedURLException {
        if (spec == null) throw new NullPointerException("spec must not be null");
        URL url = toFileURL(spec);
        if (url == null) {
            try {
                url = toURL(spec);
            } catch (MalformedURLException mfue) {
                if (baseURL == null) throw mfue;
            }
            if (url == null) {
                if (baseURL != null) {
                    url = new URL(baseURL, spec);
                } else {
                    url = null;
                }
            }
        }
        return url;
    }
    
}
