/*
 * Copyright 2004-2005 Jeremias Maerki
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.xml.graphics.stream;

import java.io.File;
import java.io.OutputStream;

import org.xml.graphics.XGResult;

/**
 * Acts as a holder for streamed output generated by an FO processor 
 * implementation.
 * 
 * @author Jeremias Maerki
 */
public class StreamXGResult extends XGResult {

    /**
     * If {@link org.xml.graphics.XGProcessorFactory#getFeature}
     * returns true when passed this value as an argument,
     * the XGProcessor supports Result output of this type.
     */
    public static final String FEATURE =
        "http://" + StreamXGResult.class.getName() + "/feature";
    
    private String mimeType;
    private OutputStream out;
    private String systemID;

    public StreamXGResult(String mimeType, OutputStream out) {
        super();
        setMIMEType(mimeType);
        setOutputStream(out);
    }
    
    public StreamXGResult(String mimeType, File targetFile) {
        super();
        setMIMEType(mimeType);
        setSystemID(targetFile);
    }
    
    public StreamXGResult(String mimeType, String systemID) {
        super();
        setMIMEType(mimeType);
        setSystemID(systemID);
    }
    
    public String getMIMEType() {
        return this.mimeType;
    }
    
    public void setMIMEType(String mimeType) {
        this.mimeType = mimeType;
    }
    
    public OutputStream getOutputStream() {
        return this.out;
    }
    
    public void setOutputStream(OutputStream out) {
        this.out = out;
    }
    
    public String getSystemID() {
        return this.systemID;
    }
    
    public void setSystemID(String systemID) {
        this.systemID = systemID;
    }
    
    public void setSystemID(File targetFile) {
        String path = targetFile.getAbsolutePath();
        if (File.separatorChar != '/') {
            path = path.replace(File.separatorChar, '/');
        }
        if (path.startsWith("/")) {
            this.systemID = "file://" + path;
        } else {
            this.systemID = "file:///" + path;
        }
    }

    public String toString() {
        return "stream: " + getMIMEType();
    }
    
}
