/*
 * Copyright 2004-2005 Jeremias Maerki
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.maerki.jaxg.fop.branch;

import javax.xml.transform.Source;
import javax.xml.transform.Transformer;
import javax.xml.transform.TransformerException;
import javax.xml.transform.TransformerFactory;
import javax.xml.transform.sax.SAXResult;

import org.xml.graphics.XGException;
import org.xml.graphics.XGResult;
import org.xml.graphics.print.DocXGResult;
import org.xml.graphics.stream.StreamXGResult;
import org.xml.graphics.helpers.AbstractXGProcessor;
import org.xml.graphics.helpers.MimeConstants;

import org.apache.avalon.framework.logger.Logger;
import org.apache.fop.render.Renderer;
import org.apache.fop.render.awt.AWTRenderer;
import org.apache.fop.render.pcl.PCLRenderer;
import org.apache.fop.render.pdf.PDFRenderer;
import org.apache.fop.render.ps.PSRenderer;
import org.apache.fop.render.svg.SVGRenderer;
import org.apache.fop.render.txt.TXTRenderer;
import org.apache.fop.render.xml.XMLRenderer;

/**
 * XGProcessor implementation for the FOP maintenance branch (FOP 0.20.5).
 * 
 * @author Jeremias Maerki
 */
public class FopBranchXGProcessor extends AbstractXGProcessor {

    private Logger logger;
    
    void setLogger(Logger logger) {
        this.logger = logger;
    }
    
    Logger getLogger() {
        return this.logger;
    }
    
    protected static Renderer createRenderer(XGResult result) {
        if (result instanceof StreamXGResult) {
            StreamXGResult sres = (StreamXGResult)result;
            if (MimeConstants.MIME_PDF.equals(sres.getMIMEType())) {
                return new PDFRenderer();
            } else if (MimeConstants.MIME_POSTSCRIPT.equals(sres.getMIMEType())) {
                return new PSRenderer();
            } else if (MimeConstants.MIME_PCL.equals(sres.getMIMEType()) 
                    || MimeConstants.MIME_PCL_ALT.equals(sres.getMIMEType())) {
                return new PCLRenderer();
            } else if (MimeConstants.MIME_SVG.equals(sres.getMIMEType())) {
                return new SVGRenderer();
            } else if (MimeConstants.MIME_PLAIN_TEXT.equals(sres.getMIMEType())) {
                return new TXTRenderer();
            } else if ("application/x-fop-areatree".equals(sres.getMIMEType())) {
                return new XMLRenderer();
            } else {
                throw new UnsupportedOperationException(
                        "MIME type not supported: " + sres.getMIMEType());
            }
        } else if (result instanceof DocXGResult) {
            return new AWTRenderer(null);
        } else {
            throw new UnsupportedOperationException("NYI");
        }
    }
    
    /**
     * @see org.xml.graphics.XGProcessor#process(javax.xml.transform.Source, org.xml.graphics.XGResult)
     */
    public void process(Source source, XGResult result) throws XGException {
        try {
            TransformerFactory factory = TransformerFactory.newInstance();
            Transformer transformer = factory.newTransformer();
            
            FopBranchXGProcessorHandler handler = new FopBranchXGProcessorHandler(this);
            handler.setResult(result);
            SAXResult saxresult = new SAXResult(handler);
            
            transformer.transform(source, saxresult);
        } catch (TransformerException e) {
            throw new XGException(e);
        }
    }

    
}
