/*
 * Copyright 2004-2005 Jeremias Maerki
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.maerki.jaxg.fop.head;

import java.io.OutputStream;

import javax.xml.transform.Source;
import javax.xml.transform.Transformer;
import javax.xml.transform.TransformerException;
import javax.xml.transform.TransformerFactory;
import javax.xml.transform.sax.SAXResult;

import org.apache.avalon.framework.configuration.Configuration;
import org.apache.fop.apps.FOUserAgent;
import org.apache.fop.render.bitmap.PNGRenderer;
import org.apache.fop.render.bitmap.TIFFRenderer;
import org.apache.fop.render.mif.MIFHandler;
import org.apache.fop.render.pcl.PCLRenderer;
import org.apache.fop.render.pdf.PDFRenderer;
import org.apache.fop.render.print.PrintRenderer;
import org.apache.fop.render.ps.PSRenderer;
import org.apache.fop.render.rtf.RTFHandler;
import org.apache.fop.render.svg.SVGRenderer;
import org.apache.fop.render.txt.TXTRenderer;
import org.apache.fop.render.xml.XMLRenderer;
import org.xml.graphics.XGException;
import org.xml.graphics.XGResult;
import org.xml.graphics.helpers.AbstractXGProcessor;
import org.xml.graphics.helpers.MimeConstants;
import org.xml.graphics.print.DocXGResult;
import org.xml.graphics.stream.StreamXGResult;

/**
 * XGProcessor implementation for Apache FOP.
 * 
 * @author Jeremias Maerki
 */
public class FopXGProcessor extends AbstractXGProcessor {

    private String baseURL = null;
    private Integer resolution = null;
    private boolean strictValidation = false;
    private Configuration userConfig = null;
    
    public FopXGProcessor() {
        //System.out.println(getClass().getName() + " " + getClass().getClassLoader());
        //System.out.println("================================================");
    }
    
    public void setBaseURL(String baseURL) {
        this.baseURL = baseURL;
    }
    
    public String getBaseURL() {
        return this.baseURL;
    }

    public void setResolution(Integer resolution) {
        this.resolution = resolution;
    }
    
    public Integer getResolution() {
        return this.resolution;
    }

    public void setStrictValidation(boolean value) {
        this.strictValidation = value;
    }
    
    public boolean isStrictValidation() {
        return this.strictValidation;
    }
    
    public void setUserConfig(Configuration cfg) {
        this.userConfig = cfg;
    }
    
    public Configuration getUserConfig() {
        return this.userConfig;
    }

    /*
    public Object getParameter(String name) {
        if (DocumentMetadata.KEY.equals(name)) {
            return this.metadata;
        } else {
            return super.getParameter(name);
        }
    }
    
    public void setParameter(String name, Object value) {
        if (DocumentMetadata.KEY.equals(name)) {
            this.metadata = (DocumentMetadata)value;
        } else {
            super.setParameter(name, value);
        }
    }*/

    protected static Object createRenderer(XGResult result, 
            FOUserAgent ua, OutputStream out) {
        if (result instanceof StreamXGResult) {
            StreamXGResult sres = (StreamXGResult)result;
            if (MimeConstants.MIME_PDF.equals(sres.getMIMEType())) {
                PDFRenderer renderer = new PDFRenderer();
                renderer.setUserAgent(ua);
                return renderer;
            } else if (MimeConstants.MIME_POSTSCRIPT.equals(sres.getMIMEType())) {
                PSRenderer renderer = new PSRenderer();
                renderer.setUserAgent(ua);
                return renderer;
            } else if (MimeConstants.MIME_PCL.equals(sres.getMIMEType()) 
                    || MimeConstants.MIME_PCL_ALT.equals(sres.getMIMEType())) {
                PCLRenderer renderer = new PCLRenderer();
                renderer.setUserAgent(ua);
                return renderer;
            } else if (MimeConstants.MIME_SVG.equals(sres.getMIMEType())) {
                SVGRenderer renderer = new SVGRenderer();
                renderer.setUserAgent(ua);
                return renderer;
            } else if (MimeConstants.MIME_PLAIN_TEXT.equals(sres.getMIMEType())) {
                TXTRenderer renderer = new TXTRenderer();
                renderer.setUserAgent(ua);
                return renderer;
            } else if ("application/x-fop-areatree".equals(sres.getMIMEType())) {
                XMLRenderer renderer = new XMLRenderer();
                renderer.setUserAgent(ua);
                return renderer;
            } else if (MimeConstants.MIME_TIFF.equals(sres.getMIMEType())) {
                TIFFRenderer renderer = new TIFFRenderer();
                renderer.setUserAgent(ua);
                return renderer;
            } else if (MimeConstants.MIME_PNG.equals(sres.getMIMEType())) {
                PNGRenderer renderer = new PNGRenderer();
                renderer.setUserAgent(ua);
                return renderer;
            } else if (MimeConstants.MIME_RTF.equals(sres.getMIMEType())
                    || MimeConstants.MIME_RTF_ALT1.equals(sres.getMIMEType())
                    || MimeConstants.MIME_RTF_ALT2.equals(sres.getMIMEType())) {
                return new RTFHandler(ua, out);
            } else if (MimeConstants.MIME_MIF.equals(sres.getMIMEType())) {
                return new MIFHandler(ua, out);
            } else {
                throw new UnsupportedOperationException(
                        "MIME type not supported: " + sres.getMIMEType());
            }
        } else if (result instanceof DocXGResult) {
            PrintRenderer renderer = new PrintRenderer();
            renderer.setUserAgent(ua);
            return renderer;
        } else {
            throw new UnsupportedOperationException("Requested result type (" 
                    + result + ") not available");
        }
    }
    
    
    public void process(Source source, XGResult result)
            throws XGException {
        try {
            TransformerFactory factory = TransformerFactory.newInstance();
            Transformer transformer = factory.newTransformer();
            
            FopXGProcessorHandler handler = new FopXGProcessorHandler();
            handler.setResult(result);
            SAXResult saxresult = new SAXResult(handler);
            
            transformer.transform(source, saxresult);
        } catch (TransformerException e) {
            throw new XGException(e);
        }
    }

}
