/*
 * Copyright 2004-2005 Jeremias Maerki
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.maerki.jaxg.fop.head;

import java.io.File;
import java.net.MalformedURLException;
import java.net.URL;

import org.apache.avalon.framework.configuration.Configuration;
import org.apache.avalon.framework.configuration.DefaultConfigurationBuilder;
import org.xml.graphics.XGException;
import org.xml.graphics.XGProcessor;
import org.xml.graphics.XGProcessorFactory;
import org.xml.graphics.XGProcessorHandler;
import org.xml.graphics.print.DocXGResult;
import org.xml.graphics.stream.StreamXGResult;

/**
 * XGProcessorFactory implementation for Apache FOP.
 * 
 * @author Jeremias Maerki
 */
public class FopXGProcessorFactory extends XGProcessorFactory {

    private String baseURL = null;
    private Integer resolution = null;
    private boolean strictValidation = false;
    private Configuration userConfig = null;
    
    private void checkMandatoryAttributes() throws XGException {
        //nop
    }

    private void configure(FopXGProcessor processor) {
        processor.setBaseURL(baseURL);
        processor.setResolution(resolution);
        processor.setStrictValidation(strictValidation);
        processor.setUserConfig(userConfig);
    }
    
    public XGProcessor newXGProcessor() throws XGException {
        checkMandatoryAttributes();
        FopXGProcessor processor = new FopXGProcessor();
        configure(processor);
        return processor;
    }

    public XGProcessorHandler newXGProcessorHandler() throws XGException {
        checkMandatoryAttributes();
        FopXGProcessorHandler handler = new FopXGProcessorHandler(); 
        configure((FopXGProcessor)handler.getXGProcessor());
        return handler;
    }

    public boolean getFeature(String name) {
        return StreamXGResult.FEATURE.equals(name)
            || DocXGResult.FEATURE.equals(name);
    }

    public void setAttribute(String name, Object value) throws IllegalArgumentException {
        if (Constants.ATTR_BASE_URL.equals(name)) {
            if (value instanceof String) {
                this.baseURL = (String)value;
            } else if (value instanceof URL) {
                this.baseURL = ((URL)value).toString();
            } else if (value instanceof File) {
                try {
                    this.baseURL = ((File)value).toURL().toString();
                } catch (MalformedURLException e) {
                    throw new IllegalArgumentException("File could not be converted to a URL: " 
                            + e.getMessage());
                }
            }
        } else if (Constants.ATTR_RESOLUTION.equals(name)) {
            if (value instanceof Integer) {
                this.resolution = (Integer)value;
            } else if (value instanceof String) {
                this.resolution = new Integer((String)value);
            } else {
                throw new IllegalArgumentException("Attribute '" 
                        + Constants.ATTR_RESOLUTION 
                        + "' must be an Integer instance.");
            }
        } else if (Constants.ATTR_STRICT_VALIDATION.equals(name)) {
            if (value instanceof Boolean) {
               this.strictValidation = ((Boolean)value).booleanValue(); 
            } else {
                throw new IllegalArgumentException("Attribute '" 
                        + Constants.ATTR_RESOLUTION + "' must be an Boolean instance.");
            }
        } else if (Constants.ATTR_USERCONFIG.equals(name)) {
            if (value instanceof Configuration) {
                this.userConfig = (Configuration)value;
            } else if (value instanceof File) {
                DefaultConfigurationBuilder cfgBuilder = new DefaultConfigurationBuilder();
                try {
                    this.userConfig = cfgBuilder.buildFromFile(((File)value));
                } catch (Exception e) {
                    throw new IllegalArgumentException("User configuration could not be loaded: "
                            + e.getMessage());
                }
            }
        }
    }

    public Object getAttribute(String name) throws IllegalArgumentException {
        throw new IllegalArgumentException("getAttribute() NYI");
    }

}
