/*
 * Copyright 2004-2005 Jeremias Maerki
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.maerki.jaxg.foray;

import javax.xml.transform.Source;
import javax.xml.transform.Transformer;
import javax.xml.transform.TransformerException;
import javax.xml.transform.TransformerFactory;
import javax.xml.transform.sax.SAXResult;

import org.apache.avalon.framework.logger.Logger;
import org.foray.app.Options;
import org.foray.area.LayoutStrategy;
import org.foray.output.OutputConfig;
import org.foray.render.Renderer;
import org.foray.render.pcl.PCLRenderer;
import org.foray.render.pdf.PDFRenderer;
import org.foray.render.ps.PSRenderer;
import org.foray.render.svg.SVGRenderer;
import org.foray.render.txt.TXTRenderer;
import org.foray.render.xml.XMLRenderer;

import org.xml.graphics.XGException;
import org.xml.graphics.XGResult;
import org.xml.graphics.helpers.AbstractXGProcessor;
import org.xml.graphics.stream.StreamXGResult;

/**
 * XGProcessor implementation for FOray (an Apache FOP fork).
 * 
 * @author Jeremias Maerki
 */
public class FOrayXGProcessor extends AbstractXGProcessor {

    private Logger logger;
    private Options options;
    private OutputConfig outputConfig;
    private LayoutStrategy layoutStrategy;
    
    void setLogger(Logger logger) {
        this.logger = logger;
    }
    
    Logger getLogger() {
        return this.logger;
    }
    
    public void setOptions(Options options) {
        this.options = options;
    }

    Options getOptions() {
        return this.options;
    }

    public void setOutputConfig(OutputConfig config) {
        this.outputConfig = config;
    }
    
    OutputConfig getRenderConfig() {
        return this.outputConfig;
    }
    
    public void setLayoutStrategy(LayoutStrategy strategy) {
        this.layoutStrategy = strategy;
    }

    LayoutStrategy getLayoutStrategy() {
        return this.layoutStrategy;
    }
    
    protected Renderer createRenderer(XGResult result) {
        if (result instanceof StreamXGResult) {
            StreamXGResult sres = (StreamXGResult)result;
            if ("application/pdf".equals(sres.getMIMEType())) {
                return new PDFRenderer(getRenderConfig());
            } else if ("application/postscript".equals(sres.getMIMEType())) {
                return new PSRenderer(getRenderConfig());
            } else if ("application/x-pcl".equals(sres.getMIMEType()) 
                    || "application/vnd.hp-PCL".equals(sres.getMIMEType())) {
                return new PCLRenderer(getRenderConfig());
            } else if ("image/svg+xml".equals(sres.getMIMEType())) {
                return new SVGRenderer(getRenderConfig());
            } else if ("text/plain".equals(sres.getMIMEType())) {
                return new TXTRenderer(getRenderConfig());
            } else if ("application/x-fop-areatree".equals(sres.getMIMEType())) {
                return new XMLRenderer(getRenderConfig());
            } else {
                throw new UnsupportedOperationException(
                        "MIME type not supported: " + sres.getMIMEType());
            }
        } else {
            throw new UnsupportedOperationException("NYI");
        }
    }
    
    public void process(Source source, XGResult result) throws XGException {
        try {
            TransformerFactory factory = TransformerFactory.newInstance();
            Transformer transformer = factory.newTransformer();
            
            FOrayXGProcessorHandler handler = new FOrayXGProcessorHandler(this);
            handler.setResult(result);
            SAXResult saxresult = new SAXResult(handler);
            
            transformer.transform(source, saxresult);
        } catch (TransformerException te) {
            throw new XGException(te);
        }
    }

    
}
