/*
 * Copyright 2004-2005 Jeremias Maerki
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.xml.graphics.test;

import java.io.File;

import javax.xml.transform.Source;
import javax.xml.transform.stream.StreamSource;

import org.xml.graphics.XGResult;
import org.xml.graphics.XGProcessor;
import org.xml.graphics.XGProcessorFactory;
import org.xml.graphics.stream.StreamXGResult;

import junit.framework.TestCase;

/**
 * @author Jeremias Maerki
 */
public abstract class XGProcessorTest extends TestCase {

    protected abstract XGProcessorFactory getFactory();
    protected File basedir;

    protected void setUp() throws Exception {
        this.basedir = new File(".");
        new File(basedir, "build/test").mkdirs();
    }

    protected String getMIMEType() {
        return "application/pdf";
    }
    
    protected String getExtension() {
        return "pdf";
    }
    
    protected File getTestFile() {
        return new File(basedir, "tck/test/xml/helloworld.fo");
    }
    
    public void testSimpleRun() throws Exception {
        XGProcessorFactory factory = getFactory();
        XGProcessor processor = factory.newXGProcessor();

        Source src = new StreamSource(getTestFile());
        XGResult xgResult = new StreamXGResult(getMIMEType(), 
                new File(basedir, "build/test/out." + getExtension()));
        
        processor.process(src, xgResult);
    }
    
}
